### derek/test_rsc_pin

Last updated: 2020-01-13 23:58:59 • Format: csv • API: v1

some description

Download data: test_rsc_pin.csv

Raw metadata

    api_version: 1
    created: 20200113T235859Z
    description: some description
    file: test_rsc_pin.csv
    file_size: 19
    pin_hash: a6cf5331bf3de6c6
    title: some pin
    type: csv
    user: {}

### Code

    from pins import board_rsconnect
    board = board_rsconnect(server_url='http://localhost:3939')
    board.pin_read("derek/test_rsc_pin")

### Preview (up to 100 rows)